==> guile-1.1.tar.gz: guile-1.1/libguile/script.h <==
/* classes: h_files */

#ifndef SCRIPTH
#define SCRIPTH
/*	Copyright (C) 1997 Free Software Foundation, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, the Free Software Foundation gives permission
 * for additional uses of the text contained in its release of GUILE.
 *
 * The exception is that, if you link the GUILE library with other files
 * to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the GUILE library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the
 * Free Software Foundation under the name GUILE.  If you copy
 * code from other Free Software Foundation releases into a copy of
 * GUILE, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for GUILE, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.  
 */

#include "libguile/__scm.h"


extern char *scm_find_executable SCM_P ((const char *name));
extern char *scm_find_impl_file SCM_P ((char *exec_path,
					const char *generic_name,
					const char *initname,
					const char *sep));
extern char **scm_get_meta_args SCM_P ((int argc, char **argv));
extern int scm_count_argv SCM_P ((char **argv));
extern void scm_shell_usage SCM_P ((int fatal, char *message));
extern SCM scm_compile_shell_switches SCM_P ((int argc, char **argv));
extern void scm_shell SCM_P ((int argc, char **argv));
extern char *scm_usage_name;
extern void scm_init_script ();

#endif  /* SCRIPTH */

==> guile_1.2.orig.tar.gz: guile-1.2/libguile/script.h <==
/* classes: h_files */

#ifndef SCRIPTH
#define SCRIPTH
/*	Copyright (C) 1997 Free Software Foundation, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307 USA
 *
 * As a special exception, the Free Software Foundation gives permission
 * for additional uses of the text contained in its release of GUILE.
 *
 * The exception is that, if you link the GUILE library with other files
 * to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the GUILE library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the
 * Free Software Foundation under the name GUILE.  If you copy
 * code from other Free Software Foundation releases into a copy of
 * GUILE, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for GUILE, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.  */

#include "libguile/__scm.h"


extern char *scm_find_executable SCM_P ((const char *name));
extern char *scm_find_impl_file SCM_P ((char *exec_path,
					const char *generic_name,
					const char *initname,
					const char *sep));
extern char **scm_get_meta_args SCM_P ((int argc, char **argv));
extern int scm_count_argv SCM_P ((char **argv));
extern void scm_shell_usage SCM_P ((int fatal, char *message));
extern SCM scm_compile_shell_switches SCM_P ((int argc, char **argv));
extern void scm_shell SCM_P ((int argc, char **argv));
extern char *scm_usage_name;
extern void scm_init_script ();

#endif  /* SCRIPTH */
